/***************************************************************************
 *            wp.h
 *
 *  Wed Jun  4 21:07:49 2008
 *  Copyright  2008  Marcus Bauer 
 *  GPLv2
 *  Email marcus.bauer@gmail.com
 ****************************************************************************/

void
paint_wp();

void
paint_myposition();

void
do_paint_wp();

GdkPixbuf *
load_wp_icon();

void
set_current_wp(double lat, double lon);

void
osd_wp();
